@@ -71,49 +71,22 @@ static	char	Filename[] = __FILE__;
 
 extern	char	**environ, **xenviron;
 
-char	*exitcodename,
-	*signalname,
-	*Curr_pwd;
-
-HelpaltRef	repunit, ifnposses, days_abbrev;
-
-FILE	*Cfile;
+char	*Curr_pwd;
 
 #define	IPC_MODE	0600
 
-int	Ctrl_chan;
-#ifndef	USING_FLOCK
-int	Sem_chan;
-#endif
-
 ULONG		indx;
 ULONG		Saveseq;
 
-uid_t	Daemuid,
-	Realuid,
-	Effuid;
-gid_t	Realgid,
-	Effgid;
-
-char	*Restru,
-	*Restrg;
-
-char	*jobqueue,		/* Dummy one to read file reqd by rjobfile */
-	*sjobqueue;		/* Job queue we are setting */
+char	*sjobqueue;		/* Job queue we are setting */
 
 int	exit_code;
 
 uid_t	New_owner;
 gid_t	New_group;
 
-char	*Args[MAXJARGS];
-
 unsigned	defavoid;
 
-BtuserRef	mypriv;
-
-long		mymtype;
-
 extern char **remread_envir(const netid_t);
 void  checksetmode(const int, const ushort *, const ushort, USHORT *);
 
@@ -1000,7 +973,7 @@ MAINFN_TYPE  main(int argc, char **argv)
 	int_ugid_t	chk_uid;
 #endif
 
-	versionprint(argv, "$Revision: 1.1.1.1 $", 0);
+	versionprint(argv, "$Revision: 1.1 $", 0);
 
 	if  ((progname = strrchr(argv[0], '/')))
 		progname++;
