@@ -57,27 +57,14 @@
 
 char	*Curr_pwd;
 
-FILE	*Cfile;
-
 #define	IPC_MODE	0600
 
-int	Ctrl_chan;
 #ifndef	USING_FLOCK
 int	Sem_chan;
 #endif
 
-uid_t	Daemuid,
-	Realuid,
-	Effuid;
-gid_t	Realgid,
-	Effgid;
-
 ULONG		indx;
 
-BtuserRef	mypriv;
-
-long		mymtype;
-
 int	killtype = SIGTERM;
 unsigned	sleeptime = DEFSLEEP;
 
@@ -86,21 +73,11 @@ int	exit_code,
 	nodel,
 	unqueue;
 
-char	*jobqueue,		/* Not actually used */
-	*Args[1],		/* Ditto */
-	*Restru,
-	*Restrg,
-	*jobprefix,
+char	*jobprefix,
 	*cmdprefix;
 
 enum	cmdtype	{ CMD_DELETE, CMD_GO, CMD_GOADV, CMD_ADV };
 
-#ifdef	SHAREDLIBS
-#include "helpalt.h"
-HelpaltRef	repunit, ifnposses, days_abbrev;
-char		*exitcodename, *signalname;
-#endif
-
 void  nomem(const char *fl, const int ln)
 {
 	fprintf(stderr, "%s:Mem alloc fault: %s line %d\n", progname, fl, ln);
