@@ -47,7 +47,7 @@ static	char	Filename[] = __FILE__;
 /* Structure used to hash user ids.  */
 
 struct	uhash	{
-	struct	uhash	*pwh_next, *pwu_next;
+	struct	uhash	*pwhuid_next, *pwhuname_next;
 	int_ugid_t	pwh_uid, pwh_dgid;
 #ifdef	HAVE_GETGROUPS
 	USHORT		pwh_nsuppgrps;
@@ -57,167 +57,21 @@ struct	uhash	{
 	char	pwh_name[1];
 };
 
-struct	fuhash  {
-	LONG		pwh_next;
-	int_ugid_t	pwh_uid;
-	int_ugid_t	pwh_dgid;
-	LONG		pwh_homed;
-#ifdef	HAVE_GETGROUPS
-	USHORT		pwh_nsuppgrps;
-	gid_t		pwh_suppglist[NGROUPS_MAX];
-#endif
-};
-
-/* Define these here */
-
 uid_t	Daemuid,
 	Realuid,
 	Effuid;
 
 int_ugid_t	lastgid;	/* Group of last user */
 
-#define	UG_HASHMOD	97
+#define	UG_HASHMOD	503
 
-char	Using_dumpfile;
 static	int	doneit;
 static	struct	uhash	*uhash[UG_HASHMOD];
 static	struct	uhash	*unhash[UG_HASHMOD];
 
-void  dump_pwfile()
-{
-	LONG	offset;
-	int	fd, hn, hdl;
-	unsigned	cnt;
-	struct	uhash	*hp;
-	char	*name = envprocess(DUMPPWFILE);
-	struct	fuhash	fh;
-	LONG	dhash[UG_HASHMOD];
+/* Number of unique userids in password file */
 
-	if  ((fd = open(name, O_WRONLY|O_CREAT|O_TRUNC, 0644)) < 0)
-		goto  zapit;
-
-	offset = UG_HASHMOD * sizeof(LONG);
-	lseek(fd, offset, 0);
-
-	for  (cnt = 0;  cnt < UG_HASHMOD;  cnt++)  {
-		dhash[cnt] = uhash[cnt]? offset: 0L;
-		for  (hp = uhash[cnt];  hp;  hp = hp->pwh_next)  {
-			fh.pwh_uid = hp->pwh_uid;
-			fh.pwh_dgid = hp->pwh_dgid;
-			hn = strlen(hp->pwh_name) + 1;
-			hdl = strlen(hp->pwh_homed) + 1;
-			offset += sizeof(struct fuhash) + hn;
-			fh.pwh_homed = offset;
-			offset += hdl;
-			fh.pwh_next = hp->pwh_next? offset: 0L;
-#ifdef	HAVE_GETGROUPS
-			if  ((fh.pwh_nsuppgrps = hp->pwh_nsuppgrps) != 0)
-				BLOCK_COPY(fh.pwh_suppglist, hp->pwh_suppglist, fh.pwh_nsuppgrps * sizeof(gid_t));
-#endif
-			if  (write(fd, (char *) &fh, sizeof(fh)) != sizeof(fh))
-				goto  zapitc;
-			if  (write(fd, hp->pwh_name, hn) != hn)
-				goto  zapitc;
-			if  (write(fd, hp->pwh_homed, hdl) != hdl)
-				goto  zapitc;
-		}
-	}
-
-	/* Dump out hash table of uids.  We'd like to do it for names
-	   but we want to be sure of preserving the order of
-	   uid->name lookups (See comment in rpwfile below); */
-
-	lseek(fd, 0L, 0);
-	if  (write(fd, (char *) dhash, sizeof(dhash)) != sizeof(dhash))
-		goto  zapitc;
-
-	close(fd);
-	free(name);
-	return;
-zapitc:
-	close(fd);
-zapit:
-	unlink(name);
-	free(name);
-}
-
-static int  undump_pwfile()
-{
-	char	*name = envprocess(DUMPPWFILE);
-	struct	uhash	*hp, **hpp;
-	unsigned	cnt;
-	int	fd, nl;
-	LONG	fp;
-	struct	fuhash	fh;
-	LONG	dhash[UG_HASHMOD];
-	char	dirbuf[PATH_MAX];
-
-	fd = open(name, O_RDONLY);
-	free(name);
-	if  (fd < 0)
-		return  0;
-	if  (read(fd, (char *) dhash, sizeof(dhash)) != sizeof(dhash))  {
-	yuk:
-		close(fd);
-		return  0;
-	}
-
-	/* Read in and reallocate the user hash table.  */
-
-	for  (cnt = 0;  cnt < UG_HASHMOD;  cnt++)  {
-		hpp = &uhash[cnt];
-		fp = dhash[cnt];
-		while  (fp)  {
-			lseek(fd, fp, 0);
-			if  (read(fd, (char *) &fh, sizeof(fh)) != sizeof(fh))
-				goto  yuk;
-
-			/* Take advantage of the fact that we write
-			   the home dirs after the hash structure
-			   to get user name length (including
-			   null char).  */
-
-			nl = fh.pwh_homed - fp - sizeof(fh);
-			fp = fh.pwh_next;
-			if  (!(hp = (struct uhash *) malloc((unsigned) (nl + sizeof(struct uhash) - 1))))
-				ABORT_NOMEM;
-			*hpp = hp;
-			hpp = &hp->pwh_next;
-			hp->pwh_uid = fh.pwh_uid;
-			hp->pwh_dgid = fh.pwh_dgid;
-			if  (read(fd, hp->pwh_name, nl) != nl)
-				goto  yuk;
-			if  (read(fd, dirbuf, sizeof(dirbuf)) <= 0)
-				goto  yuk;
-			hp->pwh_homed = stracpy(dirbuf);
-#ifdef	HAVE_GETGROUPS
-			hp->pwh_suppglist = (gid_t *) 0;
-			hp->pwh_nsuppgrps = 0;
-			if  (Requires_suppgrps  &&  (hp->pwh_nsuppgrps = fh.pwh_nsuppgrps) != 0)  {
-				if  (!(hp->pwh_suppglist = (gid_t *) malloc(fh.pwh_nsuppgrps * sizeof(gid_t))))
-					ABORT_NOMEM;
-				BLOCK_COPY(hp->pwh_suppglist, fh.pwh_suppglist, fh.pwh_nsuppgrps * sizeof(gid_t));
-			}
-#endif
-		}
-		*hpp = (struct uhash *) 0;
-	}
-	close(fd);
-	BLOCK_ZERO(unhash, sizeof(unhash));
-
-	for  (cnt = 0;  cnt < UG_HASHMOD;  cnt++)
-		for  (hp = uhash[cnt];  hp;  hp = hp->pwh_next)  {
-			char	*pn = hp->pwh_name;
-			unsigned  sum = 0;
-			while  (*pn)
-				sum += *pn++;
-			sum %= UG_HASHMOD;
-			hp->pwu_next = unhash[sum];
-			unhash[sum] = hp;
-		}
-
-	return  1;
-}
+unsigned  Npwusers;
 
 /* "unread" password file to order */
 
@@ -228,9 +82,12 @@ void  un_rpwfile()
 
 	if  (!doneit)		/* Nothing to undo */
 		return;
+
+	/* Do it by name not by uid as we might have duplicate uids which aren't hashed */
+	
 	for  (cnt = 0;  cnt < UG_HASHMOD;  cnt++)  {
-		for  (hp = uhash[cnt];  hp;  hp = np)  {
-			np = hp->pwh_next;
+		for  (hp = unhash[cnt];  hp;  hp = np)  {
+			np = hp->pwhuname_next;
 #ifdef	HAVE_GETGROUPS
 			if  (hp->pwh_nsuppgrps != 0)  {
 				hp->pwh_nsuppgrps = 0;
@@ -250,48 +107,56 @@ void  un_rpwfile()
 
 void  rpwfile()
 {
-	if  (undump_pwfile())
-		Using_dumpfile = 1; /* Turns off rgrpfile reading supp groups again */
-	else  {
-		struct  passwd  *upw;
-		struct  uhash  *hp, **hpp, **hnpp;
-		char	*pn;
-		unsigned  sum;
+	struct  passwd  *upw;
+	struct  uhash  *hp, **hpp, **hnpp;
+	char	*pn;
+	unsigned  sum;
 
-		Using_dumpfile = 0;
+	Npwusers = 0;			/* This is the number of unique IDs */
 
-		while  ((upw = getpwent()) != (struct passwd *) 0)  {
-			pn = upw->pw_name;
-			sum = 0;
-			while  (*pn)
-				sum += *pn++;
+	while  ((upw = getpwent()))  {
+		int	haduid = 0;
+		pn = upw->pw_name;
+		sum = 0;
+		while  (*pn)
+			sum += *pn++;
 
-			/* Find END of collision chain for uid lookup.
-			   This is so system ids with the same
-			   uid come out with first name in the
-			   password file.  */
+		/* Find END of collision chain for uid lookup.
+		   This is so system ids with the same
+		   uid come out with first name in the
+		   password file.  */
 
-			for  (hpp = &uhash[(ULONG) upw->pw_uid % UG_HASHMOD]; (hp = *hpp); hpp = &hp->pwh_next)
-				;
+		/* Avoid adding clashing names with the same id to the hash */
 
-			hnpp = &unhash[sum % UG_HASHMOD];
-			if  ((hp = (struct uhash *) malloc(sizeof(struct uhash) + strlen(upw->pw_name))) == (struct uhash *) 0)
-				ABORT_NOMEM;
-			hp->pwh_uid = upw->pw_uid;
-			hp->pwh_dgid = upw->pw_gid;
+		for  (hpp = &uhash[(ULONG)upw->pw_uid % UG_HASHMOD]; (hp = *hpp); hpp = &hp->pwhuid_next)
+			if  (hp->pwh_uid == upw->pw_uid)
+				haduid = 1;
+
+		hnpp = &unhash[sum % UG_HASHMOD];
+		if  ((hp = (struct uhash *) malloc(sizeof(struct uhash) + strlen(upw->pw_name))) == (struct uhash *) 0)
+			ABORT_NOMEM;
+		hp->pwh_uid = upw->pw_uid;
+		hp->pwh_dgid = upw->pw_gid;
 #ifdef	HAVE_GETGROUPS
-			hp->pwh_nsuppgrps = 0;
-			hp->pwh_suppglist = (gid_t *) 0;
+		hp->pwh_nsuppgrps = 0;
+		hp->pwh_suppglist = (gid_t *) 0;
 #endif
-			hp->pwh_homed = stracpy(upw->pw_dir);
-			strcpy(hp->pwh_name, upw->pw_name);
-			hp->pwh_next = *hpp;
-			hp->pwu_next = *hnpp;
+		hp->pwh_homed = stracpy(upw->pw_dir);
+		strcpy(hp->pwh_name, upw->pw_name);
+
+		/* Add to user id hash if unique id and bump the number of users */
+		if  (haduid)
+			hp->pwhuid_next = 0;
+		else  {
+			hp->pwhuid_next = *hpp;
 			*hpp = hp;
-			*hnpp = hp;
+			Npwusers++;
 		}
-		endpwent();
+		/* Always add the name to the name hash to look up id */
+		hp->pwhuname_next = *hnpp;
+		*hnpp = hp;
 	}
+	endpwent();
 	doneit = 1;
 }
 
@@ -309,7 +174,7 @@ static struct uhash *luid_lookup(const uid_t uid)
 	while  (hp)  {
 		if  (uid == hp->pwh_uid)
 			return  hp;
-		hp = hp->pwh_next;
+		hp = hp->pwhuid_next;
 	}
 	return	(struct uhash *) 0;
 }
@@ -318,7 +183,7 @@ static struct uhash *luid_lookup(const uid_t uid)
 
 static struct uhash *luname_lookup(const char *name)
 {
-	const	 char	*cp;
+	const  char  *cp;
 	unsigned  sum = 0;
 	struct  uhash  *hp;
 
@@ -331,7 +196,7 @@ static struct uhash *luname_lookup(const char *name)
 	while  (hp)  {
 		if  (strcmp(name, hp->pwh_name) == 0)
 			return  hp;
-		hp = hp->pwu_next;
+		hp = hp->pwhuname_next;
 	}
 	return  (struct uhash *) 0;
 }
@@ -383,7 +248,7 @@ char *homedof(const int_ugid_t uid)
 /* Loop over all known user ids, calling the supplied function with
    argument arg and uid.  */
 
-void	uloop_over(int fid, void (*fn)(int, char *, int_ugid_t), char *arg)
+void	uloop_over(void (*fn)(char *, int_ugid_t), char *arg)
 {
 	struct  uhash  *hp;
 	unsigned	hi;
@@ -391,8 +256,8 @@ void	uloop_over(int fid, void (*fn)(int, char *, int_ugid_t), char *arg)
 	if  (!doneit)
 		rpwfile();
 	for  (hi = 0;  hi < UG_HASHMOD;  hi++)
-		for  (hp = uhash[hi];  hp;  hp = hp->pwh_next)
-			(*fn)(fid, arg, hp->pwh_uid);
+		for  (hp = uhash[hi];  hp;  hp = hp->pwhuid_next)
+			(*fn)(arg, hp->pwh_uid);
 }
 
 /* Generate a matrix for use when prompting for user names */
@@ -420,7 +285,7 @@ char **gen_ulist(const char *prefix)
 		sfl = strlen(prefix);
 
 	for  (hi = 0;  hi < UG_HASHMOD;  hi++)
-		for  (hp = uhash[hi];  hp;  hp = hp->pwh_next)  {
+		for  (hp = uhash[hi];  hp;  hp = hp->pwhuid_next)  {
 
 			/* Skip ones which don't match the prefix */
 
@@ -448,7 +313,7 @@ char **gen_ulist(const char *prefix)
 /* Process string to extract ~username constructs or ~ for $HOME ~+
    for $PWD if it exists ~- for $OLDPWD if it exists */
 
-char *unameproc(char *str, const char *currdir, const uid_t realuid)
+char  *unameproc(char *str, const char *currdir, const uid_t realuid)
 {
 	char	*ep, *cp, *newstr;
 	const	char	*ins;
