@@ -16,8 +16,8 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 #include "config.h"
-static	char	rcsid1[] = "@(#) $Id: xmbtr.c,v 1.1.1.1 2009/02/18 06:51:32 toadwarble Exp $";		/* We use these in the about message */
-static	char	rcsid2[] = "@(#) $Revision: 1.1.1.1 $";
+static	char	rcsid1[] = "@(#) $Id: xmbtr.c,v 1.1 2009/02/18 06:51:32 toadwarble Exp $";		/* We use these in the about message */
+static	char	rcsid2[] = "@(#) $Revision: 1.1 $";
 #include <stdio.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -79,29 +79,13 @@ static	char	rcsid2[] = "@(#) $Revision: 1.1.1.1 $";
 void  initcifile();
 
 char	*spdir,
-	*Curr_pwd,
-	*jobqueue;
-
-uid_t	Daemuid,
-	Realuid,
-	Effuid;
-
-gid_t	Realgid,
-	Effgid;
+	*Curr_pwd;
 
 extern	USHORT	Save_umask;
 
-FILE	*Cfile;
 char	Confvarname[] = "XMBTRCONF";
 
-int	Ctrl_chan = -1;
-#ifndef	USING_FLOCK
-int	Sem_chan;
-#endif
-
-long	mymtype;
-
-BtuserRef	mypriv;
+extern	long	mymtype;
 
 struct	pend_job	default_pend;
 Btjob	default_job;
@@ -110,8 +94,6 @@ char	xterm_edit;		/* Invoke "xterm" to run editor */
 
 char	*editor_name;	/* Name of favourite editor */
 
-char	*Restru, *Restrg;
-
 /* X Stuff */
 
 XtAppContext	app;
@@ -547,7 +529,7 @@ MAINFN_TYPE  main(int argc, char **argv)
 	struct	sigstruct_name	z;
 #endif
 
-	versionprint(argv, "$Revision: 1.1.1.1 $", 0);
+	versionprint(argv, "$Revision: 1.1 $", 0);
 
 	if  ((progname = strrchr(argv[0], '/')))
 		progname++;
