@@ -44,17 +44,8 @@
 #include "cgiutil.h"
 #include "rcgilib.h"
 
-FILE	*Cfile;
-
-uid_t	Daemuid,
-	Realuid,
-	Effuid;
-gid_t	Realgid,
-	Effgid;
-
-int	xbapi_fd = -1, Nvars;
+int	Nvars;
 struct	var_with_slot  *var_sl_list;
-apiBtuser	mypriv;
 
 void  nomem(const char *fl, const int ln)
 {
@@ -99,7 +90,7 @@ MAINFN_TYPE  main(int argc, char **argv)
 	char	*realuname, **newargs;
 	int_ugid_t	chku;
 
-	versionprint(argv, "$Revision: 1.1.1.1 $", 0);
+	versionprint(argv, "$Revision: 1.1 $", 0);
 
 	if  ((progname = strrchr(argv[0], '/')))
 		progname++;
